@@ -1,8 +1,8 @@
 from django.urls import path
 
 from arq_admin.views import (
-    AllJobListView, DeferredJobListView, JobDetailView, QueuedJobListView,
-    QueueListView, RunningJobListView,
+    AllJobListView, DeferredJobListView, JobAbortView, JobDetailView,
+    QueuedJobListView, QueueListView, RunningJobListView,
 )
 
 app_name = 'arq_admin'
@@ -13,4 +13,5 @@ urlpatterns = [
     path('queue/<str:queue_name>/running/', RunningJobListView.as_view(), name='running_jobs'),
     path('queue/<str:queue_name>/deferred/', DeferredJobListView.as_view(), name='deferred_jobs'),
     path('queue/<str:queue_name>/<str:job_id>/', JobDetailView.as_view(), name='job_detail'),
+    path('queue/<str:queue_name>/<str:job_id>/abort', JobAbortView.as_view(), name='job_abort'),
 ]
